@@ -22,9 +22,9 @@ NO_MISSION     = -2
 WT_NOT_RUNNING = -3
 OTHER_ERROR    = -4
 METRICS_PLANES = ['p-', 'f-', 'f2', 'f3', 'f4', 'f6', 'f7', 'f8', 'f9', 'os',
-                  'sb', 'tb', 'a-', 'pb', 'am', 'ad', 'fj', 'b-', 'xp', 'bt',
-                  'xa', 'xf', 'sp', 'hu', 'ty', 'fi', 'gl', 'ni', 'fu', 'fu',
-                  'se', 'bl', 'be', 'su', 'te', 'st', 'mo', 'we', 'ha']
+                  'sb', 'tb', 'a-', 'pb', 'am', 'ad', 'fj', 'b-', 'b_', 'xp',
+                  'bt', 'xa', 'xf', 'sp', 'hu', 'ty', 'fi', 'gl', 'ni', 'fu',
+                  'fu', 'se', 'bl', 'be', 'su', 'te', 'st', 'mo', 'we', 'ha']
 
 
 def combine_dicts(to_dict, from_dict):
